<?php

/**
 * @file
 * Actions for Pimport module.
 */

/**
 * Implementation of hook_action_info().
 */
function pimport_action_info() {
  return array(
    'pimport_export_nodes_csv_action' => array(
      'type' => 'node',
      'description' => t('Export nodes as CSV'),
      'configurable' => TRUE,
      'aggregate' => TRUE,
      'hooks' => array('any' => TRUE),
    ),
  );
} // pimport_action_info

/**
 * Implementation of hook_(action)_form().
 *
 * @param $context
 *   Array containing View information and Object (which is an array of the selected node ids {node}.nid).
 *
 * @return
 *   Returns Drupal form array for rendering.
 *
 * @see pimport_action_info(), pimport_export_nodes_csv_action_submit(), pimport_export_nodes_csv_action()
 */
function pimport_export_nodes_csv_action_form($context) {
  global $user;
  $form['profile'] = array(
    '#type' => 'select',
    '#title' => t('Profile'),
    '#description' => t('Select which profile to use for this export.'),
    '#options' => pimport_fetch_profiles(array(), 'names'),
    '#default_value' => !empty($user->pimport_default_profile) ? $user->pimport_default_profile : variable_get('pimport_default_profile', NULL),
  );
  $form['filename'] = array(
    '#type' => 'textfield',
    '#title' => t('Filename'),
    '#description' => t('Set a filename for this export, it will be appended with the current date.'),
    '#default_value' => module_exists('token') ? '[site-name]' : 'metadata',
  );
  if (module_exists('token')) {
    $form['tokens'] = array(
      '#type' => 'fieldset',
      '#title' => t('Available tokens'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['tokens']['values'] = array(
      '#type' => 'markup',
      '#value' => theme('token_help', 'global'),
    );
  }
  return $form;
} // pimport_export_nodes_csv_action_form

/**
 * Implementation of hook_(action)_submit().
 *
 * @param $form
 *   Drupal form array.
 * @param $form_state
 *   Drupal form_state array.
 *
 * @see pimport_action_info(), pimport_export_nodes_csv_action_form(), pimport_export_nodes_csv_action()
 */
function pimport_export_nodes_csv_action_submit($form, $form_state) {
  pimport_check_export_dir();
  return array(
    'profile' => $form_state['values']['profile'],
    'filename' => $form_state['values']['filename'],
  );
} // pimport_export_nodes_csv_submit

/**
 * Action callback for pimport_export_nodes_csv_action().
 *
 * @param $object
 *   Contains an array of node ids {node}.nid.
 * @param $context
 *   Contains all the Actions related information, including the results of the forms the users filled out to fire this Action.
 *
 * @see pimport_action_info(), pimport_export_nodes_csv_action_form(), pimport_export_nodes_csv_action_submit()
 */
function pimport_export_nodes_csv_action(&$object, $context) {
  $filename = module_exists('token') ? token_replace($context['filename']) : $context['filename'];
  pimport_export_multiple_nodes($object, $context['profile'], $filename, 'CSV');
} // pimport_export_nodes_csv_action